/* DASHBOARD */

.dashboard .module table th {
  width: 100%;
}

.dashboard .module table td {
  white-space: nowrap;
}

.dashboard .module table td a {
  display: block;
  padding: 0;
}

/* RECENT ACTIONS MODULE */

.module ul.actionlist {
  margin-left: 0;
}

ul.actionlist li {
  list-style-type: none;
  overflow: hidden;
  text-overflow: ellipsis;
}
